summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/common/scominfo/p9_scominfo.H
diff options
context:
space:
mode:
authorBen Gass <bgass@us.ibm.com>2017-02-14 03:06:01 -0600
committerDaniel M. Crowell <dcrowell@us.ibm.com>2017-02-23 10:54:39 -0500
commit067163534e2acd38d47bf45378bb90c875f5dc43 (patch)
treeb8d4c0ed5d0caaf64837e4bb9a338d51979dc3f9 /src/import/chips/p9/common/scominfo/p9_scominfo.H
parent9a631c770d3252b2309eba5cf6b5a07a6067dd97 (diff)
downloadtalos-hostboot-067163534e2acd38d47bf45378bb90c875f5dc43.tar.gz
talos-hostboot-067163534e2acd38d47bf45378bb90c875f5dc43.zip
Updating NV scom address xlate for dd2.
Change-Id: I7d6dea78895807554b692f3ca9696a3de2ba8986 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/36411 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Dev-Ready: Brent Wieman <bwieman@us.ibm.com> Reviewed-by: Brent Wieman <bwieman@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/36428 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com>
Diffstat (limited to 'src/import/chips/p9/common/scominfo/p9_scominfo.H')
-rw-r--r--src/import/chips/p9/common/scominfo/p9_scominfo.H11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/import/chips/p9/common/scominfo/p9_scominfo.H b/src/import/chips/p9/common/scominfo/p9_scominfo.H
index fdabb9f1c..38c74888a 100644
--- a/src/import/chips/p9/common/scominfo/p9_scominfo.H
+++ b/src/import/chips/p9/common/scominfo/p9_scominfo.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2015,2016 */
+/* Contributors Listed Below - COPYRIGHT 2015,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -44,7 +44,12 @@
extern "C"
{
- static const uint32_t PPE_MODE = 1;
+ //Modes for scominfo functions
+ static const uint32_t P9N_DD1_SI_MODE = 0x0;
+ static const uint32_t PPE_MODE = 0x1;
+ static const uint32_t P9N_DD2_SI_MODE = 0x2;
+ static const uint32_t P9C_DD1_SI_MODE = 0x4;
+ static const uint32_t P9C_DD2_SI_MODE = 0x8;
typedef enum
{
@@ -60,7 +65,7 @@ extern "C"
/// @param[in] i_p9CU Enumeration of the chip unit type
/// @param[in] i_chipUnitNum Instance number of the chip unit
/// @param[in] i_scomAddr The input SCOM address associated with the chip unit type
/// @param[in] i_mode Used for special purposes, default to 0
/// @retval uint64_t Actual SCOM address for the chip unit instance passed in
uint64_t p9_scominfo_createChipUnitScomAddr(const p9ChipUnits_t i_p9CU, const uint8_t i_chipUnitNum,
const uint64_t i_scomAddr, const uint32_t i_mode = 0);
@@ -60,7 +65,7 @@ extern "C"
/// @param[in] i_chipUnitNum Instance number of the chip unit
/// @param[in] i_scomAddr The input SCOM address associated with the chip unit type
- /// @param[in] i_mode Used for special purposes, default to 0
+ /// @param[in] i_mode Used for special purposes, default to 0 = p9n dd1, 1 = ppe_mode, 2 = p9n dd2, 4 = p9c dd1, 8 = p9c dd2
/// @retval uint64_t Actual SCOM address for the chip unit instance passed in
uint64_t p9_scominfo_createChipUnitScomAddr(const p9ChipUnits_t i_p9CU, const uint8_t i_chipUnitNum,
OpenPOWER on IntegriCloud